@@ -16,7 +16,7 @@ Configuration parameters:
         False: disable Do Not Disturb on startup
         True: enable Do Not Disturb on startup
         last: toggle last known state on startup
-        None: don't toggle anything on startup
+        None: query current state from notification manager (doesn't work on dunst)
         (default 'last')
     thresholds: specify color thresholds to use
         (default [(0, 'bad'), (1, 'good')])
@@ -33,6 +33,9 @@ Dunst Miscellaneous:
     notifications in a queue. This can for example be wrapped around a screen
     locker (i3lock, slock) to prevent flickering of notifications through the
     lock and to read all missed notifications after returning to the computer.
+    This means that by default (pause = False), all notifications sent while
+    DND is active will NOT be queued and displayed when DND is deactivated.
+
 
 Examples:
 ```
@@ -49,7 +52,7 @@ do_not_disturb {
 # display DO NOT DISTURB/DISTURB
 do_not_disturb {
     format = '[\?color=state [\?if=state DO NOT DISTURB|DISTURB]]'
-    thresholds = [(0, 'darkgray'), (1, 'good')]
+    thresholds = [(0, "darkgray"), (1, "good")]
 }
 ```
 
@@ -58,10 +61,10 @@ do_not_disturb {
 @license BSD
 
 SAMPLE OUTPUT
-[{'full_text': 'dunst '}, {'color': '#00FF00', 'full_text': 'DND'}]
+[{'full_text': 'Dunst '}, {'color': '#00FF00', 'full_text': 'DND'}]
 
 off
-[{'full_text': 'dunst '}, {'color': '#FF0000', 'full_text': 'DND'}]
+[{'full_text': 'Dunst '}, {'color': '#FF0000', 'full_text': 'DND'}]
 """
 
 STRING_NOT_INSTALLED = "server `{}` not installed"
@@ -87,9 +90,16 @@ class Dunst(Notification):
     """
 
     def toggle(self, state):
-        self.parent.py3.command_run(
-            "killall --signal {} dunst".format(self.parent.signals[state])
-        )
+        if state:
+            # pause
+            self.parent.py3.command_run("pkill -SIGUSR1 dunst")
+        else:
+            if self.parent.pause:
+                # resume
+                self.parent.py3.command_run("pkill -SIGUSR2 dunst")
+            else:
+                # delete all pending notifications and resume
+                self.parent.py3.command_run("pkill -SIGTERM dunst")
 
 
 class Xfce4_notifyd(Notification):
@@ -145,10 +155,6 @@ class Py3status:
                 raise Exception(STRING_NOT_INSTALLED.format(command))
 
         if self.server == "dunst":
-            if self.pause:
-                self.signals = ("SIGUSR2", "SIGUSR1")  # pause/resume
-            else:
-                self.signals = ("SIGTERM", "SIGUSR1")  # kill/resume
             self.backend = Dunst(self)
         elif self.server == "xfce4-notifyd":
             self.backend = Xfce4_notifyd(self)
@@ -160,6 +166,8 @@ class Py3status:
                 self.backend.toggle(self.state)
             else:
                 raise Exception(STRING_INVALID_STATE.format(self.state))
+        elif self.server == "dunst":
+            raise Exception(STRING_INVALID_STATE.format(self.state))
 
         self.name = self.server.capitalize()
         self.thresholds_init = self.py3.get_color_names_list(self.format)
